#! /usr/local/bin/python3


"""
A sample simple pipeline
By JZ, 20181218
"""


import numpy as np
from astropy.io import fits
from matplotlib import pyplot as plt
import os


def photo(img_fits, cat_fits):
    """
    sample
    """
    cmd = 'sex img/{} -CATALOG_NAME cat/{}'.format(img_fits, cat_fits)
    os.system(cmd)

    img = fits.getdata('img/' + img_fits)
    cat = fits.getdata('cat/' + cat_fits, 2)
    print('Load image and catalog')

    img_med = np.median(img)
    img_std = np.std(img)
    
    fig = plt.figure(figsize=(12, 12))
    ax = fig.add_subplot(111)
    ax.imshow(img, 
          vmax=img_med + 1.5 * img_std, 
          vmin=img_med - 0.5 * img_std, 
          cmap='gray')
    ax.plot(cat['X_IMAGE']-1, cat['Y_IMAGE'] -1, 'rx')
    fig.savefig('fig/' + img_fits + '.eps')
    fig.savefig('fig/' + img_fits + '.png')
    plt.close(fig)
    print('Draw image')
    
    fig = plt.figure(figsize=(12, 5))
    ax = fig.add_subplot(111)
    ax.plot(cat['MAG_APER'] + 25.0, cat['MAGERR_APER'], '.')
    ax.set_xlabel('Mag')
    ax.set_ylabel('Error')
    ax.set_xlim(10, 20)
    ax.set_ylim(-0.01, 0.25)
    ax.set_title('Mag-Err')
    fig.savefig('fig/' + img_fits + '.magerr.eps')
    fig.savefig('fig/' + img_fits + '.magerr.png')
    plt.close(fig)
    print('Plot mag-err')
    
    fig = plt.figure(figsize=(12, 12))
    ax = fig.add_subplot(111)
    ax.plot(cat['ALPHA_J2000'], cat['DELTA_J2000'], 'rx')
    ax.set_xlabel("$\\alpha$ (deg)")
    ax.set_ylabel("$\\delta$ (deg)")
    fig.savefig('fig/' + img_fits + '.sky.eps')
    fig.savefig('fig/' + img_fits + '.sky.png')
    plt.close(fig)
    print('Plot sky')
    
    print('Done!')

if __name__ == "__main__":
    photo('sample.fits', 'sample.cat.fits')
    